@@ -15,15 +15,15 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#define ARROW_VERSION_MAJOR 18
-#define ARROW_VERSION_MINOR 1
-#define ARROW_VERSION_PATCH 0
+#define ARROW_VERSION_MAJOR 19
+#define ARROW_VERSION_MINOR 0
+#define ARROW_VERSION_PATCH 1
 #define ARROW_VERSION ((ARROW_VERSION_MAJOR * 1000) + ARROW_VERSION_MINOR) * 1000 + ARROW_VERSION_PATCH
 
-#define ARROW_VERSION_STRING "18.1.0"
+#define ARROW_VERSION_STRING "19.0.1"
 
-#define ARROW_SO_VERSION "1801"
-#define ARROW_FULL_SO_VERSION "1801.0.0"
+#define ARROW_SO_VERSION "1900"
+#define ARROW_FULL_SO_VERSION "1900.1.0"
 
 #define ARROW_CXX_COMPILER_ID "GNU"
 #define ARROW_CXX_COMPILER_VERSION "14.2.1"
@@ -44,7 +44,7 @@
 #define ARROW_JEMALLOC
 #define ARROW_JEMALLOC_VENDORED
 #define ARROW_JSON
-/* #undef ARROW_MIMALLOC */
+#define ARROW_MIMALLOC
 #define ARROW_ORC
 #define ARROW_PARQUET
 #define ARROW_SUBSTRAIT
